# AUTOGENERATED! DO NOT EDIT! File to edit: notebooks/FDIC_Banks.ipynb (unless otherwise specified).

__all__ = ['banks', 'banks', 'banks', 'banks', 'banks']

# Cell
banks = gpd.read_file('BCityBanks_2019_CSACity.shp')
banks = banks.fillna('Baltimore City')
banks['count'] = 1
banks= banks[['CSA','count']]
banks = banks.groupby('CSA').sum(numeric_only=True)
# Make sure ALL csas and BaltimoreCity are included. among other things
banks = csa[ ['CSA2010','tpop10'] ].merge( banks, left_on='CSA2010', right_on='CSA', how='outer' )
# Update the baltimore CSA.
banks.at[55,'count'] = banks['count'].sum()
banks.head(3)

# Cell
# Create the Indicator
banks['banks19'] = banks['count'] * 1000 / banks['tpop10']
