# AUTOGENERATED! DO NOT EDIT! File to edit: notebooks/00_core.ipynb (unless otherwise specified).

__all__ = ['core_test_fn', 'check_labels']

# Cell
def core_test_fn(txt):
  return txt + txt + txt + txt

# Cell
def check_labels(ds):
  original = ds.copy()
  original.rename(columns={ 'CSA':'CSA2010', 'BaltCity':'InBaltimore'}, inplace=True)
  df = original[ original['CSA2010'].notnull() | original['InBaltimore'].notnull()  ]
  print( 'Total # Rows: ', original.shape[0] ) # rows, columns
  print( '# Before | After')
  print( '# Where BCity.isnull/notnull: ', original.InBaltimore.isnull().sum(), '|', original.InBaltimore.notnull().sum() );
  print( '# where CSA2010.isnull/notnull: ', original.CSA2010.isnull().sum(), '|', original.CSA2010.notnull().sum() );
  print( '# Where CSA and/or Baltimore lbl Exists: ', df.shape[0])
  df.CSA2010 = df.CSA2010.fillna('Baltimore City')
  return df