# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"core_test_fn": "00_core.ipynb",
         "check_labels": "00_core.ipynb",
         "HEADER": "01_Close Crawl.ipynb",
         "URL": "01_Close Crawl.ipynb",
         "CASE_PAT": "01_Close Crawl.ipynb",
         "CASE_TYPES": "01_Close Crawl.ipynb",
         "HTML_DIR": "01_Close Crawl.ipynb",
         "HTML_FILE": "01_Close Crawl.ipynb",
         "CHECKPOINT": "01_Close Crawl.ipynb",
         "NO_CASE": "01_Close Crawl.ipynb",
         "FEATURES": "01_Close Crawl.ipynb",
         "FIELDS": "01_Close Crawl.ipynb",
         "INTERNAL_FIELDS": "01_Close Crawl.ipynb",
         "Session": "01_Close Crawl.ipynb",
         "Spider": "01_Close Crawl.ipynb",
         "scrape": "01_Close Crawl.ipynb",
         "filter_addr": "01_Close Crawl.ipynb",
         "PUNCTUATION": "01_Close Crawl.ipynb",
         "street_address": "01_Close Crawl.ipynb",
         "TITLE_SPLIT_PAT": "01_Close Crawl.ipynb",
         "ZIP_STR": "01_Close Crawl.ipynb",
         "ZIP_PAT": "01_Close Crawl.ipynb",
         "MONEY_STR": "01_Close Crawl.ipynb",
         "MONEY_PAT": "01_Close Crawl.ipynb",
         "NULL_ADDR": "01_Close Crawl.ipynb",
         "STRIP_ADDR": "01_Close Crawl.ipynb",
         "Miner": "01_Close Crawl.ipynb",
         "temp_output": "01_Close Crawl.ipynb",
         "file_array": "01_Close Crawl.ipynb",
         "top5": "01_Close Crawl.ipynb",
         "Cleaner": "01_Close Crawl.ipynb",
         "output": "01_Close Crawl.ipynb",
         "df_obj": "01_Close Crawl.ipynb",
         "close_crawl": "01_Close Crawl.ipynb",
         "args": "01_Close Crawl.ipynb",
         "runTidyAddr": "02_TidyAddr.ipynb",
         "affordm": "04_Create_Acs_Indicators_Original.ipynb",
         "affordr": "04_Create_Acs_Indicators_Original.ipynb",
         "age5": "05_Create_Acs_Indicators.ipynb",
         "age18": "05_Create_Acs_Indicators.ipynb",
         "age24": "04_Create_Acs_Indicators_Original.ipynb",
         "age64": "04_Create_Acs_Indicators_Original.ipynb",
         "age65": "05_Create_Acs_Indicators.ipynb",
         "bahigher": "04_Create_Acs_Indicators_Original.ipynb",
         "carpool": "04_Create_Acs_Indicators_Original.ipynb",
         "drvalone": "04_Create_Acs_Indicators_Original.ipynb",
         "elheat": "04_Create_Acs_Indicators_Original.ipynb",
         "empl": "04_Create_Acs_Indicators_Original.ipynb",
         "fam": "04_Create_Acs_Indicators_Original.ipynb",
         "female": "04_Create_Acs_Indicators_Original.ipynb",
         "femhhs": "04_Create_Acs_Indicators_Original.ipynb",
         "heatgas": "04_Create_Acs_Indicators_Original.ipynb",
         "hh25inc": "05_Create_Acs_Indicators.ipynb",
         "hh40inc": "04_Create_Acs_Indicators_Original.ipynb",
         "hh60inc": "04_Create_Acs_Indicators_Original.ipynb",
         "hh75inc": "04_Create_Acs_Indicators_Original.ipynb",
         "hhchpov": "04_Create_Acs_Indicators_Original.ipynb",
         "hhm75": "04_Create_Acs_Indicators_Original.ipynb",
         "hhpov": "04_Create_Acs_Indicators_Original.ipynb",
         "hhs": "04_Create_Acs_Indicators_Original.ipynb",
         "hsdipl": "04_Create_Acs_Indicators_Original.ipynb",
         "lesshs": "04_Create_Acs_Indicators_Original.ipynb",
         "male": "04_Create_Acs_Indicators_Original.ipynb",
         "mhhi": "05_Create_Acs_Indicators.ipynb",
         "nilf": "04_Create_Acs_Indicators_Original.ipynb",
         "nohhint": "05_Create_Acs_Indicators.ipynb",
         "novhcl": "05_Create_Acs_Indicators.ipynb",
         "othrcom": "04_Create_Acs_Indicators_Original.ipynb",
         "p2more": "04_Create_Acs_Indicators_Original.ipynb",
         "paa": "05_Create_Acs_Indicators.ipynb",
         "pasi": "04_Create_Acs_Indicators_Original.ipynb",
         "phisp": "04_Create_Acs_Indicators_Original.ipynb",
         "ppac": "04_Create_Acs_Indicators_Original.ipynb",
         "pubtran": "04_Create_Acs_Indicators_Original.ipynb",
         "pwhite": "05_Create_Acs_Indicators.ipynb",
         "racdiv": "04_Create_Acs_Indicators_Original.ipynb",
         "retrieve_acs_data": "90_ACS_Explore_and_Download.ipynb",
         "sclemp": "04_Create_Acs_Indicators_Original.ipynb",
         "tpop": "04_Create_Acs_Indicators_Original.ipynb",
         "trav14": "04_Create_Acs_Indicators_Original.ipynb",
         "trav29": "04_Create_Acs_Indicators_Original.ipynb",
         "trav44": "05_Create_Acs_Indicators.ipynb",
         "trav45": "05_Create_Acs_Indicators.ipynb",
         "unempl": "04_Create_Acs_Indicators_Original.ipynb",
         "unempr": "04_Create_Acs_Indicators_Original.ipynb",
         "walked": "04_Create_Acs_Indicators_Original.ipynb",
         "getColName": "05_Create_Acs_Indicators.ipynb",
         "getColByName": "05_Create_Acs_Indicators.ipynb",
         "addKey": "05_Create_Acs_Indicators.ipynb",
         "nullIfEqual": "05_Create_Acs_Indicators.ipynb",
         "sumInts": "05_Create_Acs_Indicators.ipynb",
         "hisp": "05_Create_Acs_Indicators.ipynb",
         "createAcsIndicator": "05_Create_Acs_Indicators.ipynb",
         "InteractiveShell.ast_node_interactivity": "90_ACS_Explore_and_Download.ipynb",
         "eattend": "BCPSS_Schools.ipynb",
         "mattend": "BCPSS_Schools.ipynb",
         "hsattend": "BCPSS_Schools.ipynb",
         "aastud": "BCPSS_Schools.ipynb",
         "wstud": "BCPSS_Schools.ipynb",
         "hstud": "BCPSS_Schools.ipynb",
         "abse": "BCPSS_Schools.ipynb",
         "absmd": "BCPSS_Schools.ipynb",
         "abshd": "BCPSS_Schools.ipynb",
         "drop": "BCPSS_Schools.ipynb",
         "compl": "BCPSS_Schools.ipynb",
         "sclsw": "BCPSS_Schools.ipynb",
         "eenrol": "BCPSS_Schools.ipynb",
         "menrol": "BCPSS_Schools.ipynb",
         "hsenrol": "BCPSS_Schools.ipynb",
         "taxlien": "Bidbalt_TaxSale_Taxlien.ipynb",
         "dirtyst": "CitiStat_Dirtyst_Clogged.ipynb",
         "clogged": "CitiStat_Dirtyst_Clogged.ipynb",
         "lights": "CitiStat_Dirtyst_Clogged.ipynb",
         "fin": "City_Liquor_Board_Permits.ipynb",
         "homtax": "CityFinance_histaxhometaxowntax.ipynb",
         "liquor": "City_Liquor_Board_Permits.ipynb",
         "tanf": "DHR_SNAP_TANF_Create.ipynb",
         "snap": "DHR_SNAP_TANF_Create.ipynb",
         "fdf": "TreeBaltimore_TreePlnt.ipynb",
         "findf": "TreeBaltimore_TreePlnt.ipynb",
         "faresCsa": "FARES_Salpr_Shome.ipynb",
         "salepr": "FARES_Salpr_Shome.ipynb",
         "shomes": "FARES_Salpr_Shome.ipynb",
         "banks": "FDIC_Banks.ipynb",
         "df": "HUD.ipynb",
         "cdf": "HUD.ipynb",
         "cdf2": "HUD.ipynb",
         "totemp": "Infousa.ipynb",
         "sml": "Infousa.ipynb",
         "smlbus": "Infousa.ipynb",
         "biz1": "Infousa.ipynb",
         "biz2": "Infousa.ipynb",
         "biz4": "Infousa.ipynb",
         "neiind": "Infousa.ipynb",
         "neibus": "Infousa.ipynb",
         "neiemp": "Infousa.ipynb",
         "totalres": "Mdprop_Permits_Fore_Vac Vio.ipynb",
         "ownroc": "Mdprop_Permits_Fore_Vac Vio.ipynb",
         "vacantsCsa": "Mdprop_Permits_Fore_Vac Vio.ipynb",
         "baltvac": "Mdprop_Permits_Fore_Vac Vio.ipynb",
         "vio": "Mdprop_Permits_Fore_Vac Vio.ipynb",
         "start_date": "Mdprop_Permits_Fore_Vac Vio.ipynb",
         "end_date": "Mdprop_Permits_Fore_Vac Vio.ipynb",
         "mask": "Mdprop_Permits_Fore_Vac Vio.ipynb",
         "mask1": "Mdprop_Permits_Fore_Vac Vio.ipynb",
         "mask2": "Mdprop_Permits_Fore_Vac Vio.ipynb",
         "fore": "Mdprop_Permits_Fore_Vac Vio.ipynb",
         "resrehab": "Mdprop_Permits_Fore_Vac Vio.ipynb",
         "use": "Mdprop_Permits_Fore_Vac Vio.ipynb",
         "demper": "Mdprop_Permits_Fore_Vac Vio.ipynb",
         "filter": "Mdprop_Permits_Fore_Vac Vio.ipynb",
         "constper": "Mdprop_Permits_Fore_Vac Vio.ipynb",
         "comprop": "Mdprop_Permits_Fore_Vac Vio.ipynb",
         "crehab": "Mdprop_Permits_Fore_Vac Vio.ipynb",
         "vsDom": "RBIntel.ipynb",
         "cashsa": "RBIntel.ipynb",
         "reosa": "RBIntel.ipynb"}

modules = ["utils.py",
           "closecrawl.py",
           "tidyaddr.py",
           "indicators.py",
           "create.py",
           "acsDownload.py",
           "BCPSS.py",
           "bpd.py",
           "bidbaltimore.py",
           "citistat.py",
           "cityfinance.py",
           "liquor.py",
           "dhr.py",
           "enoch.py",
           "fares.py",
           "fdic.py",
           "HUD.py",
           "infousa.py",
           "mdprop.py",
           "rbintel.py",
           "treebaltimore.py"]

doc_url = "https://bnia.github.io/VitalSigns/"

git_url = "https://github.com/bnia/VitalSigns/tree/main/"

def custom_doc_links(name): return None
